buffet: Remove 'chromeos' namespace and move everything to buffet NS

As discussed, moved all the classes out of chromeos namespace into
'buffet.

Also fixed a number of cpplint's warnings.

BUG=None
TEST=Everything still compiles and unit tests succeed.

Change-Id: Ide864acb2504627404966727f66d353af60e531d
Reviewed-on: https://chromium-review.googlesource.com/198971
Reviewed-by: Christopher Wiley <wiley@chromium.org>
Commit-Queue: Alex Vakulenko <avakulenko@chromium.org>
Tested-by: Alex Vakulenko <avakulenko@chromium.org>
diff --git a/buffet/string_utils.h b/buffet/string_utils.h
index 3fad204..95da72d 100644
--- a/buffet/string_utils.h
+++ b/buffet/string_utils.h
@@ -6,9 +6,10 @@
 #define BUFFET_STRING_UTILS_H_
 
 #include <string>
+#include <utility>
 #include <vector>
 
-namespace chromeos {
+namespace buffet {
 namespace string_utils {
 
 // Treats the string as a delimited list of substrings and returns the array
@@ -35,7 +36,7 @@
 std::string Join(const std::string& delimiter,
                  const std::string& str1, const std::string& str2);
 
-} // namespace string_utils
-} // namespace chromeos
+}  // namespace string_utils
+}  // namespace buffet
 
-#endif // BUFFET_STRING_UTILS_H_
+#endif  // BUFFET_STRING_UTILS_H_